<?php

$lan = array(

'Add new admin' => 'Add new admin',
'Administrators' => 'Administrators',
'Find an admin' => 'Find an admin',
'Show' => 'Show',
'Import list of admins' => 'Import list of admins',
'Admin added' => 'Admin added',
'Listing admin' => 'Listing admin',
'Listing admin 1 to 50' => 'Listing admin 1 to 50',
'You cannot delete yourself' => 'You cannot delete yourself',
);
?>